'use strict';

var web3_js = require('@solana/web3.js');

// src/pdas.ts
async function findAssociatedTokenAccountPda(seeds, config = {}) {
  const {
    programAddress = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL"
  } = config;
  return await web3_js.getProgramDerivedAddress({
    programAddress,
    seeds: [
      web3_js.getAddressEncoder().encode(seeds.owner),
      web3_js.getAddressEncoder().encode(seeds.tokenProgram),
      web3_js.getAddressEncoder().encode(seeds.mint)
    ]
  });
}
async function findMetadataPda(seeds, config = {}) {
  const {
    programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s"
  } = config;
  return await web3_js.getProgramDerivedAddress({
    programAddress,
    seeds: [
      web3_js.getUtf8Encoder().encode("metadata"),
      web3_js.getAddressEncoder().encode(programAddress),
      web3_js.getAddressEncoder().encode(seeds.mint)
    ]
  });
}
async function findEditionPda(seeds, config = {}) {
  const {
    programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s"
  } = config;
  return await web3_js.getProgramDerivedAddress({
    programAddress,
    seeds: [
      web3_js.getUtf8Encoder().encode("metadata"),
      web3_js.getAddressEncoder().encode(programAddress),
      web3_js.getAddressEncoder().encode(seeds.mint),
      web3_js.getUtf8Encoder().encode("edition")
    ]
  });
}
async function findTokenRecordPda(seeds, config = {}) {
  const {
    programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s"
  } = config;
  return await web3_js.getProgramDerivedAddress({
    programAddress,
    seeds: [
      web3_js.getUtf8Encoder().encode("metadata"),
      web3_js.getAddressEncoder().encode(programAddress),
      web3_js.getAddressEncoder().encode(seeds.mint),
      web3_js.getUtf8Encoder().encode("token_record"),
      web3_js.getAddressEncoder().encode(seeds.token)
    ]
  });
}
async function findWnsApprovePda(seeds, config = {}) {
  const {
    programAddress = "wns1gDLt8fgLcGhWi5MqAqgXpwEP1JftKE9eZnXS1HM"
  } = config;
  return await web3_js.getProgramDerivedAddress({
    programAddress,
    seeds: [
      web3_js.getUtf8Encoder().encode("approve-account"),
      web3_js.getAddressEncoder().encode(seeds.mint)
    ]
  });
}
async function findWnsDistributionPda(seeds, config = {}) {
  const {
    programAddress = "diste3nXmK7ddDTs1zb6uday6j4etCa9RChD8fJ1xay"
  } = config;
  return await web3_js.getProgramDerivedAddress({
    programAddress,
    seeds: [
      web3_js.getAddressEncoder().encode(seeds.collection),
      web3_js.getAddressEncoder().encode(
        seeds.paymentMint ?? web3_js.address("11111111111111111111111111111111")
      )
    ]
  });
}
async function findExtraAccountMetasPda(seeds, config) {
  return await web3_js.getProgramDerivedAddress({
    programAddress: config.programAddress,
    seeds: [
      web3_js.getUtf8Encoder().encode("extra-account-metas"),
      web3_js.getAddressEncoder().encode(seeds.mint)
    ]
  });
}
async function findFeeVaultPda(seeds) {
  const bytes = web3_js.getAddressEncoder().encode(seeds.address);
  const lastByte = bytes[bytes.length - 1];
  return await web3_js.getProgramDerivedAddress({
    programAddress: web3_js.address("TFEEgwDP6nn1s8mMX2tTNPPz8j2VomkphLUmyxKm17A"),
    seeds: [
      web3_js.getUtf8Encoder().encode("fee_vault"),
      web3_js.getU8Encoder().encode(lastByte)
    ]
  });
}
async function findNftReceiptPda(seeds, config) {
  return await web3_js.getProgramDerivedAddress({
    programAddress: config.programAddress,
    seeds: [
      web3_js.getUtf8Encoder().encode("nft_receipt"),
      web3_js.getAddressEncoder().encode(seeds.mint),
      web3_js.getAddressEncoder().encode(seeds.state)
    ]
  });
}
var resolveMetadata = async ({
  accounts
}) => {
  return {
    value: await findMetadataPda({
      mint: expectAddress(accounts.mint?.value)
    })
  };
};
var resolveEditionFromTokenStandard = async ({
  accounts,
  args
}) => {
  switch (args.tokenStandard) {
    case 0 /* NonFungible */:
    case 3 /* NonFungibleEdition */:
    case 4 /* ProgrammableNonFungible */:
    case 5 /* ProgrammableNonFungibleEdition */:
      return {
        value: await findEditionPda({
          mint: expectAddress(accounts.mint?.value)
        })
      };
    default:
      return { value: null };
  }
};
var resolveOwnerTokenRecordFromTokenStandard = async ({
  accounts,
  args
}) => {
  return args.tokenStandard === 4 /* ProgrammableNonFungible */ || args.tokenStandard === 5 /* ProgrammableNonFungibleEdition */ ? {
    value: await findTokenRecordPda({
      mint: expectAddress(accounts.mint?.value),
      token: expectAddress(accounts.ownerAta?.value)
    })
  } : { value: null };
};
var resolveListTokenRecordFromTokenStandard = async ({
  accounts,
  args
}) => {
  return args.tokenStandard === 4 /* ProgrammableNonFungible */ || args.tokenStandard === 5 /* ProgrammableNonFungibleEdition */ ? {
    value: await findTokenRecordPda({
      mint: expectAddress(accounts.mint?.value),
      token: expectAddress(accounts.listAta?.value)
    })
  } : { value: null };
};
var resolveBidTokenRecordFromTokenStandard = async ({
  accounts,
  args
}) => {
  return args.tokenStandard === 4 /* ProgrammableNonFungible */ || args.tokenStandard === 5 /* ProgrammableNonFungibleEdition */ ? {
    value: await findTokenRecordPda({
      mint: expectAddress(accounts.mint?.value),
      token: expectAddress(accounts.bidAta?.value)
    })
  } : { value: null };
};
var resolveBuyerTokenRecordFromTokenStandard = async ({
  accounts,
  args
}) => {
  return args.tokenStandard === 4 /* ProgrammableNonFungible */ || args.tokenStandard === 5 /* ProgrammableNonFungibleEdition */ ? {
    value: await findTokenRecordPda({
      mint: expectAddress(accounts.mint?.value),
      token: expectAddress(accounts.buyerAta?.value)
    })
  } : { value: null };
};
var resolveSellerTokenRecordFromTokenStandard = async ({
  accounts,
  args
}) => {
  return args.tokenStandard === 4 /* ProgrammableNonFungible */ || args.tokenStandard === 5 /* ProgrammableNonFungibleEdition */ ? {
    value: await findTokenRecordPda({
      mint: expectAddress(accounts.mint?.value),
      token: expectAddress(accounts.sellerAta?.value)
    })
  } : { value: null };
};
var resolveSourceTokenRecordFromTokenStandard = async ({
  accounts,
  args
}) => {
  return args.tokenStandard === 4 /* ProgrammableNonFungible */ || args.tokenStandard === 5 /* ProgrammableNonFungibleEdition */ ? {
    value: await findTokenRecordPda({
      mint: expectAddress(accounts.mint?.value),
      token: expectAddress(accounts.sourceAta?.value)
    })
  } : { value: null };
};
var resolveDestinationTokenRecordFromTokenStandard = async ({
  accounts,
  args
}) => {
  return args.tokenStandard === 4 /* ProgrammableNonFungible */ || args.tokenStandard === 5 /* ProgrammableNonFungibleEdition */ ? {
    value: await findTokenRecordPda({
      mint: expectAddress(accounts.mint?.value),
      token: expectAddress(accounts.destinationAta?.value)
    })
  } : { value: null };
};
var resolvePoolTokenRecordFromTokenStandard = async ({
  accounts,
  args
}) => {
  return args.tokenStandard === 4 /* ProgrammableNonFungible */ || args.tokenStandard === 5 /* ProgrammableNonFungibleEdition */ ? {
    value: await findTokenRecordPda({
      mint: expectAddress(accounts.mint?.value),
      token: expectAddress(accounts.poolAta?.value)
    })
  } : { value: null };
};
var resolveTokenMetadataProgramFromTokenStandard = ({
  args
}) => {
  return args.tokenStandard === 4 /* ProgrammableNonFungible */ || args.tokenStandard === 5 /* ProgrammableNonFungibleEdition */ ? {
    value: "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s"
  } : { value: null };
};
var resolveAuthorizationRulesProgramFromTokenStandard = ({
  args
}) => {
  return args.tokenStandard === 4 /* ProgrammableNonFungible */ || args.tokenStandard === 5 /* ProgrammableNonFungibleEdition */ ? {
    value: "auth9SigNpDKz4sJJ1DfCTuZrZNSAgh9sFD3rboVmgg"
  } : { value: null };
};
var resolveSysvarInstructionsFromTokenStandard = ({
  args
}) => {
  return args.tokenStandard === 4 /* ProgrammableNonFungible */ || args.tokenStandard === 5 /* ProgrammableNonFungibleEdition */ ? {
    value: "Sysvar1nstructions1111111111111111111111111"
  } : { value: null };
};
var resolveListAta = async ({
  accounts
}) => {
  return {
    value: await findAssociatedTokenAccountPda({
      owner: expectAddress(accounts.listState?.value),
      mint: expectAddress(accounts.mint?.value),
      tokenProgram: expectAddress(accounts.tokenProgram?.value)
    })
  };
};
var resolveBidAta = async ({
  accounts
}) => {
  return {
    value: await findAssociatedTokenAccountPda({
      owner: expectAddress(accounts.bidState?.value),
      mint: expectAddress(accounts.mint?.value),
      tokenProgram: expectAddress(accounts.tokenProgram?.value)
    })
  };
};
var resolveOwnerAta = async ({
  accounts
}) => {
  return {
    value: await findAssociatedTokenAccountPda({
      owner: expectAddress(accounts.owner?.value),
      mint: expectAddress(accounts.mint?.value),
      tokenProgram: expectAddress(accounts.tokenProgram?.value)
    })
  };
};
var resolveBuyerAta = async ({
  accounts
}) => {
  return {
    value: await findAssociatedTokenAccountPda({
      owner: expectAddress(accounts.buyer?.value),
      mint: expectAddress(accounts.mint?.value),
      tokenProgram: expectAddress(accounts.tokenProgram?.value)
    })
  };
};
var resolveSellerAta = async ({
  accounts
}) => {
  return {
    value: await findAssociatedTokenAccountPda({
      owner: expectAddress(accounts.seller?.value),
      mint: expectAddress(accounts.mint?.value),
      tokenProgram: expectAddress(accounts.tokenProgram?.value)
    })
  };
};
var resolveSourceAta = async ({
  accounts
}) => {
  return {
    value: await findAssociatedTokenAccountPda({
      owner: expectAddress(accounts.source?.value),
      mint: expectAddress(accounts.mint?.value),
      tokenProgram: expectAddress(accounts.tokenProgram?.value)
    })
  };
};
var resolveDestinationAta = async ({
  accounts
}) => {
  return {
    value: await findAssociatedTokenAccountPda({
      owner: expectAddress(accounts.destination?.value),
      mint: expectAddress(accounts.mint?.value),
      tokenProgram: expectAddress(accounts.tokenProgram?.value)
    })
  };
};
var resolvePoolAta = async ({
  accounts
}) => {
  return {
    value: await findAssociatedTokenAccountPda({
      owner: expectAddress(accounts.pool?.value),
      mint: expectAddress(accounts.mint?.value),
      tokenProgram: expectAddress(accounts.tokenProgram?.value)
    })
  };
};
var resolvePoolNftReceipt = async ({
  accounts
}) => {
  return {
    value: await findNftReceiptPda(
      {
        mint: expectAddress(accounts.mint?.value),
        state: expectAddress(accounts.pool?.value)
      },
      { programAddress: web3_js.address("TAMMqgJYcquwwj2tCdNUerh4C2bJjmghijVziSEf5tA") }
    )
  };
};
var resolveOrderNftReceipt = async ({
  accounts
}) => {
  return {
    value: await findNftReceiptPda(
      {
        mint: expectAddress(accounts.mint?.value),
        state: expectAddress(accounts.orderState?.value)
      },
      { programAddress: web3_js.address("TLoCKic2wGJm7VhZKumih4Lc35fUhYqVMgA4j389Buk") }
    )
  };
};
var resolveWnsApprovePda = async ({
  accounts
}) => {
  return {
    value: await findWnsApprovePda({
      mint: expectAddress(accounts.mint?.value)
    })
  };
};
var resolveWnsDistributionPda = async ({
  args
}) => {
  return {
    value: await findWnsDistributionPda({
      collection: expectAddress(args.collection),
      paymentMint: args.paymentMint
    })
  };
};
var resolveWnsExtraAccountMetasPda = async ({
  accounts
}) => {
  return {
    value: await findExtraAccountMetasPda(
      {
        mint: expectAddress(accounts.mint?.value)
      },
      { programAddress: expectAddress(accounts.wnsProgram?.value) }
    )
  };
};

// src/types.ts
var TokenStandard = /* @__PURE__ */ ((TokenStandard2) => {
  TokenStandard2[TokenStandard2["NonFungible"] = 0] = "NonFungible";
  TokenStandard2[TokenStandard2["FungibleAsset"] = 1] = "FungibleAsset";
  TokenStandard2[TokenStandard2["Fungible"] = 2] = "Fungible";
  TokenStandard2[TokenStandard2["NonFungibleEdition"] = 3] = "NonFungibleEdition";
  TokenStandard2[TokenStandard2["ProgrammableNonFungible"] = 4] = "ProgrammableNonFungible";
  TokenStandard2[TokenStandard2["ProgrammableNonFungibleEdition"] = 5] = "ProgrammableNonFungibleEdition";
  return TokenStandard2;
})(TokenStandard || {});

// src/index.ts
function expectAddress(value) {
  if (!value) {
    throw new Error("Expected a Address.");
  }
  if (typeof value === "object" && "address" in value) {
    return value.address;
  }
  if (Array.isArray(value)) {
    return value[0];
  }
  return value;
}

exports.TokenStandard = TokenStandard;
exports.expectAddress = expectAddress;
exports.findAssociatedTokenAccountPda = findAssociatedTokenAccountPda;
exports.findEditionPda = findEditionPda;
exports.findExtraAccountMetasPda = findExtraAccountMetasPda;
exports.findFeeVaultPda = findFeeVaultPda;
exports.findMetadataPda = findMetadataPda;
exports.findNftReceiptPda = findNftReceiptPda;
exports.findTokenRecordPda = findTokenRecordPda;
exports.findWnsApprovePda = findWnsApprovePda;
exports.findWnsDistributionPda = findWnsDistributionPda;
exports.resolveAuthorizationRulesProgramFromTokenStandard = resolveAuthorizationRulesProgramFromTokenStandard;
exports.resolveBidAta = resolveBidAta;
exports.resolveBidTokenRecordFromTokenStandard = resolveBidTokenRecordFromTokenStandard;
exports.resolveBuyerAta = resolveBuyerAta;
exports.resolveBuyerTokenRecordFromTokenStandard = resolveBuyerTokenRecordFromTokenStandard;
exports.resolveDestinationAta = resolveDestinationAta;
exports.resolveDestinationTokenRecordFromTokenStandard = resolveDestinationTokenRecordFromTokenStandard;
exports.resolveEditionFromTokenStandard = resolveEditionFromTokenStandard;
exports.resolveListAta = resolveListAta;
exports.resolveListTokenRecordFromTokenStandard = resolveListTokenRecordFromTokenStandard;
exports.resolveMetadata = resolveMetadata;
exports.resolveOrderNftReceipt = resolveOrderNftReceipt;
exports.resolveOwnerAta = resolveOwnerAta;
exports.resolveOwnerTokenRecordFromTokenStandard = resolveOwnerTokenRecordFromTokenStandard;
exports.resolvePoolAta = resolvePoolAta;
exports.resolvePoolNftReceipt = resolvePoolNftReceipt;
exports.resolvePoolTokenRecordFromTokenStandard = resolvePoolTokenRecordFromTokenStandard;
exports.resolveSellerAta = resolveSellerAta;
exports.resolveSellerTokenRecordFromTokenStandard = resolveSellerTokenRecordFromTokenStandard;
exports.resolveSourceAta = resolveSourceAta;
exports.resolveSourceTokenRecordFromTokenStandard = resolveSourceTokenRecordFromTokenStandard;
exports.resolveSysvarInstructionsFromTokenStandard = resolveSysvarInstructionsFromTokenStandard;
exports.resolveTokenMetadataProgramFromTokenStandard = resolveTokenMetadataProgramFromTokenStandard;
exports.resolveWnsApprovePda = resolveWnsApprovePda;
exports.resolveWnsDistributionPda = resolveWnsDistributionPda;
exports.resolveWnsExtraAccountMetasPda = resolveWnsExtraAccountMetasPda;
//# sourceMappingURL=out.js.map
//# sourceMappingURL=index.js.map