import { getProgramDerivedAddress, getAddressEncoder, getUtf8Encoder, address, getU8Encoder } from '@solana/web3.js';

// src/pdas.ts
async function findAssociatedTokenAccountPda(seeds, config = {}) {
  const {
    programAddress = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL"
  } = config;
  return await getProgramDerivedAddress({
    programAddress,
    seeds: [
      getAddressEncoder().encode(seeds.owner),
      getAddressEncoder().encode(seeds.tokenProgram),
      getAddressEncoder().encode(seeds.mint)
    ]
  });
}
async function findMetadataPda(seeds, config = {}) {
  const {
    programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s"
  } = config;
  return await getProgramDerivedAddress({
    programAddress,
    seeds: [
      getUtf8Encoder().encode("metadata"),
      getAddressEncoder().encode(programAddress),
      getAddressEncoder().encode(seeds.mint)
    ]
  });
}
async function findEditionPda(seeds, config = {}) {
  const {
    programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s"
  } = config;
  return await getProgramDerivedAddress({
    programAddress,
    seeds: [
      getUtf8Encoder().encode("metadata"),
      getAddressEncoder().encode(programAddress),
      getAddressEncoder().encode(seeds.mint),
      getUtf8Encoder().encode("edition")
    ]
  });
}
async function findTokenRecordPda(seeds, config = {}) {
  const {
    programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s"
  } = config;
  return await getProgramDerivedAddress({
    programAddress,
    seeds: [
      getUtf8Encoder().encode("metadata"),
      getAddressEncoder().encode(programAddress),
      getAddressEncoder().encode(seeds.mint),
      getUtf8Encoder().encode("token_record"),
      getAddressEncoder().encode(seeds.token)
    ]
  });
}
async function findWnsApprovePda(seeds, config = {}) {
  const {
    programAddress = "wns1gDLt8fgLcGhWi5MqAqgXpwEP1JftKE9eZnXS1HM"
  } = config;
  return await getProgramDerivedAddress({
    programAddress,
    seeds: [
      getUtf8Encoder().encode("approve-account"),
      getAddressEncoder().encode(seeds.mint)
    ]
  });
}
async function findWnsDistributionPda(seeds, config = {}) {
  const {
    programAddress = "diste3nXmK7ddDTs1zb6uday6j4etCa9RChD8fJ1xay"
  } = config;
  return await getProgramDerivedAddress({
    programAddress,
    seeds: [
      getAddressEncoder().encode(seeds.collection),
      getAddressEncoder().encode(
        seeds.paymentMint ?? address("11111111111111111111111111111111")
      )
    ]
  });
}
async function findExtraAccountMetasPda(seeds, config) {
  return await getProgramDerivedAddress({
    programAddress: config.programAddress,
    seeds: [
      getUtf8Encoder().encode("extra-account-metas"),
      getAddressEncoder().encode(seeds.mint)
    ]
  });
}
async function findFeeVaultPda(seeds) {
  const bytes = getAddressEncoder().encode(seeds.address);
  const lastByte = bytes[bytes.length - 1];
  return await getProgramDerivedAddress({
    programAddress: address("TFEEgwDP6nn1s8mMX2tTNPPz8j2VomkphLUmyxKm17A"),
    seeds: [
      getUtf8Encoder().encode("fee_vault"),
      getU8Encoder().encode(lastByte)
    ]
  });
}
async function findNftReceiptPda(seeds, config) {
  return await getProgramDerivedAddress({
    programAddress: config.programAddress,
    seeds: [
      getUtf8Encoder().encode("nft_receipt"),
      getAddressEncoder().encode(seeds.mint),
      getAddressEncoder().encode(seeds.state)
    ]
  });
}
var resolveMetadata = async ({
  accounts
}) => {
  return {
    value: await findMetadataPda({
      mint: expectAddress(accounts.mint?.value)
    })
  };
};
var resolveEditionFromTokenStandard = async ({
  accounts,
  args
}) => {
  switch (args.tokenStandard) {
    case 0 /* NonFungible */:
    case 3 /* NonFungibleEdition */:
    case 4 /* ProgrammableNonFungible */:
    case 5 /* ProgrammableNonFungibleEdition */:
      return {
        value: await findEditionPda({
          mint: expectAddress(accounts.mint?.value)
        })
      };
    default:
      return { value: null };
  }
};
var resolveOwnerTokenRecordFromTokenStandard = async ({
  accounts,
  args
}) => {
  return args.tokenStandard === 4 /* ProgrammableNonFungible */ || args.tokenStandard === 5 /* ProgrammableNonFungibleEdition */ ? {
    value: await findTokenRecordPda({
      mint: expectAddress(accounts.mint?.value),
      token: expectAddress(accounts.ownerAta?.value)
    })
  } : { value: null };
};
var resolveListTokenRecordFromTokenStandard = async ({
  accounts,
  args
}) => {
  return args.tokenStandard === 4 /* ProgrammableNonFungible */ || args.tokenStandard === 5 /* ProgrammableNonFungibleEdition */ ? {
    value: await findTokenRecordPda({
      mint: expectAddress(accounts.mint?.value),
      token: expectAddress(accounts.listAta?.value)
    })
  } : { value: null };
};
var resolveBidTokenRecordFromTokenStandard = async ({
  accounts,
  args
}) => {
  return args.tokenStandard === 4 /* ProgrammableNonFungible */ || args.tokenStandard === 5 /* ProgrammableNonFungibleEdition */ ? {
    value: await findTokenRecordPda({
      mint: expectAddress(accounts.mint?.value),
      token: expectAddress(accounts.bidAta?.value)
    })
  } : { value: null };
};
var resolveBuyerTokenRecordFromTokenStandard = async ({
  accounts,
  args
}) => {
  return args.tokenStandard === 4 /* ProgrammableNonFungible */ || args.tokenStandard === 5 /* ProgrammableNonFungibleEdition */ ? {
    value: await findTokenRecordPda({
      mint: expectAddress(accounts.mint?.value),
      token: expectAddress(accounts.buyerAta?.value)
    })
  } : { value: null };
};
var resolveSellerTokenRecordFromTokenStandard = async ({
  accounts,
  args
}) => {
  return args.tokenStandard === 4 /* ProgrammableNonFungible */ || args.tokenStandard === 5 /* ProgrammableNonFungibleEdition */ ? {
    value: await findTokenRecordPda({
      mint: expectAddress(accounts.mint?.value),
      token: expectAddress(accounts.sellerAta?.value)
    })
  } : { value: null };
};
var resolveSourceTokenRecordFromTokenStandard = async ({
  accounts,
  args
}) => {
  return args.tokenStandard === 4 /* ProgrammableNonFungible */ || args.tokenStandard === 5 /* ProgrammableNonFungibleEdition */ ? {
    value: await findTokenRecordPda({
      mint: expectAddress(accounts.mint?.value),
      token: expectAddress(accounts.sourceAta?.value)
    })
  } : { value: null };
};
var resolveDestinationTokenRecordFromTokenStandard = async ({
  accounts,
  args
}) => {
  return args.tokenStandard === 4 /* ProgrammableNonFungible */ || args.tokenStandard === 5 /* ProgrammableNonFungibleEdition */ ? {
    value: await findTokenRecordPda({
      mint: expectAddress(accounts.mint?.value),
      token: expectAddress(accounts.destinationAta?.value)
    })
  } : { value: null };
};
var resolvePoolTokenRecordFromTokenStandard = async ({
  accounts,
  args
}) => {
  return args.tokenStandard === 4 /* ProgrammableNonFungible */ || args.tokenStandard === 5 /* ProgrammableNonFungibleEdition */ ? {
    value: await findTokenRecordPda({
      mint: expectAddress(accounts.mint?.value),
      token: expectAddress(accounts.poolAta?.value)
    })
  } : { value: null };
};
var resolveTokenMetadataProgramFromTokenStandard = ({
  args
}) => {
  return args.tokenStandard === 4 /* ProgrammableNonFungible */ || args.tokenStandard === 5 /* ProgrammableNonFungibleEdition */ ? {
    value: "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s"
  } : { value: null };
};
var resolveAuthorizationRulesProgramFromTokenStandard = ({
  args
}) => {
  return args.tokenStandard === 4 /* ProgrammableNonFungible */ || args.tokenStandard === 5 /* ProgrammableNonFungibleEdition */ ? {
    value: "auth9SigNpDKz4sJJ1DfCTuZrZNSAgh9sFD3rboVmgg"
  } : { value: null };
};
var resolveSysvarInstructionsFromTokenStandard = ({
  args
}) => {
  return args.tokenStandard === 4 /* ProgrammableNonFungible */ || args.tokenStandard === 5 /* ProgrammableNonFungibleEdition */ ? {
    value: "Sysvar1nstructions1111111111111111111111111"
  } : { value: null };
};
var resolveListAta = async ({
  accounts
}) => {
  return {
    value: await findAssociatedTokenAccountPda({
      owner: expectAddress(accounts.listState?.value),
      mint: expectAddress(accounts.mint?.value),
      tokenProgram: expectAddress(accounts.tokenProgram?.value)
    })
  };
};
var resolveBidAta = async ({
  accounts
}) => {
  return {
    value: await findAssociatedTokenAccountPda({
      owner: expectAddress(accounts.bidState?.value),
      mint: expectAddress(accounts.mint?.value),
      tokenProgram: expectAddress(accounts.tokenProgram?.value)
    })
  };
};
var resolveOwnerAta = async ({
  accounts
}) => {
  return {
    value: await findAssociatedTokenAccountPda({
      owner: expectAddress(accounts.owner?.value),
      mint: expectAddress(accounts.mint?.value),
      tokenProgram: expectAddress(accounts.tokenProgram?.value)
    })
  };
};
var resolveBuyerAta = async ({
  accounts
}) => {
  return {
    value: await findAssociatedTokenAccountPda({
      owner: expectAddress(accounts.buyer?.value),
      mint: expectAddress(accounts.mint?.value),
      tokenProgram: expectAddress(accounts.tokenProgram?.value)
    })
  };
};
var resolveSellerAta = async ({
  accounts
}) => {
  return {
    value: await findAssociatedTokenAccountPda({
      owner: expectAddress(accounts.seller?.value),
      mint: expectAddress(accounts.mint?.value),
      tokenProgram: expectAddress(accounts.tokenProgram?.value)
    })
  };
};
var resolveSourceAta = async ({
  accounts
}) => {
  return {
    value: await findAssociatedTokenAccountPda({
      owner: expectAddress(accounts.source?.value),
      mint: expectAddress(accounts.mint?.value),
      tokenProgram: expectAddress(accounts.tokenProgram?.value)
    })
  };
};
var resolveDestinationAta = async ({
  accounts
}) => {
  return {
    value: await findAssociatedTokenAccountPda({
      owner: expectAddress(accounts.destination?.value),
      mint: expectAddress(accounts.mint?.value),
      tokenProgram: expectAddress(accounts.tokenProgram?.value)
    })
  };
};
var resolvePoolAta = async ({
  accounts
}) => {
  return {
    value: await findAssociatedTokenAccountPda({
      owner: expectAddress(accounts.pool?.value),
      mint: expectAddress(accounts.mint?.value),
      tokenProgram: expectAddress(accounts.tokenProgram?.value)
    })
  };
};
var resolvePoolNftReceipt = async ({
  accounts
}) => {
  return {
    value: await findNftReceiptPda(
      {
        mint: expectAddress(accounts.mint?.value),
        state: expectAddress(accounts.pool?.value)
      },
      { programAddress: address("TAMMqgJYcquwwj2tCdNUerh4C2bJjmghijVziSEf5tA") }
    )
  };
};
var resolveOrderNftReceipt = async ({
  accounts
}) => {
  return {
    value: await findNftReceiptPda(
      {
        mint: expectAddress(accounts.mint?.value),
        state: expectAddress(accounts.orderState?.value)
      },
      { programAddress: address("TLoCKic2wGJm7VhZKumih4Lc35fUhYqVMgA4j389Buk") }
    )
  };
};
var resolveWnsApprovePda = async ({
  accounts
}) => {
  return {
    value: await findWnsApprovePda({
      mint: expectAddress(accounts.mint?.value)
    })
  };
};
var resolveWnsDistributionPda = async ({
  args
}) => {
  return {
    value: await findWnsDistributionPda({
      collection: expectAddress(args.collection),
      paymentMint: args.paymentMint
    })
  };
};
var resolveWnsExtraAccountMetasPda = async ({
  accounts
}) => {
  return {
    value: await findExtraAccountMetasPda(
      {
        mint: expectAddress(accounts.mint?.value)
      },
      { programAddress: expectAddress(accounts.wnsProgram?.value) }
    )
  };
};

// src/types.ts
var TokenStandard = /* @__PURE__ */ ((TokenStandard2) => {
  TokenStandard2[TokenStandard2["NonFungible"] = 0] = "NonFungible";
  TokenStandard2[TokenStandard2["FungibleAsset"] = 1] = "FungibleAsset";
  TokenStandard2[TokenStandard2["Fungible"] = 2] = "Fungible";
  TokenStandard2[TokenStandard2["NonFungibleEdition"] = 3] = "NonFungibleEdition";
  TokenStandard2[TokenStandard2["ProgrammableNonFungible"] = 4] = "ProgrammableNonFungible";
  TokenStandard2[TokenStandard2["ProgrammableNonFungibleEdition"] = 5] = "ProgrammableNonFungibleEdition";
  return TokenStandard2;
})(TokenStandard || {});

// src/index.ts
function expectAddress(value) {
  if (!value) {
    throw new Error("Expected a Address.");
  }
  if (typeof value === "object" && "address" in value) {
    return value.address;
  }
  if (Array.isArray(value)) {
    return value[0];
  }
  return value;
}

export { TokenStandard, expectAddress, findAssociatedTokenAccountPda, findEditionPda, findExtraAccountMetasPda, findFeeVaultPda, findMetadataPda, findNftReceiptPda, findTokenRecordPda, findWnsApprovePda, findWnsDistributionPda, resolveAuthorizationRulesProgramFromTokenStandard, resolveBidAta, resolveBidTokenRecordFromTokenStandard, resolveBuyerAta, resolveBuyerTokenRecordFromTokenStandard, resolveDestinationAta, resolveDestinationTokenRecordFromTokenStandard, resolveEditionFromTokenStandard, resolveListAta, resolveListTokenRecordFromTokenStandard, resolveMetadata, resolveOrderNftReceipt, resolveOwnerAta, resolveOwnerTokenRecordFromTokenStandard, resolvePoolAta, resolvePoolNftReceipt, resolvePoolTokenRecordFromTokenStandard, resolveSellerAta, resolveSellerTokenRecordFromTokenStandard, resolveSourceAta, resolveSourceTokenRecordFromTokenStandard, resolveSysvarInstructionsFromTokenStandard, resolveTokenMetadataProgramFromTokenStandard, resolveWnsApprovePda, resolveWnsDistributionPda, resolveWnsExtraAccountMetasPda };
//# sourceMappingURL=out.js.map
//# sourceMappingURL=index.mjs.map